<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Sistem İzleyici</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Sistem İzleyici, sisteminizde çalışan gerçek zamanlı sistem yükünü izlemek, görüntülemek ve kontrol etmek için kullanılan bir araçtır.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Ayrıntıları gizle</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Oku</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Yaz</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 saniye</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 gün %2 saat %3 dakika</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Kullanım</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Şuanki frekans</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekans</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Sağlayan</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Soketler</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Mantıksal işlemciler</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Sanallaştırma</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i önbelleği</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d önbelleği</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 önbelleği</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 önbelleği</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Ortalama yük</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Dosya tanımlayıcıları</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>İşlemler</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Çekirdekler</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Ana bilgisayar adı</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>OS türü</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Açık kalma süresi</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 saniye</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktif</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>yeniden yükleniyor</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>pasif</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>başarısız</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>aktifleştiriliyor</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>etkisizleştiriliyor</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>taslak</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>bulunamadı</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>kötü ayar</translation>
    </message>
    <message>
        <source>error</source>
        <translation>hata</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>birleşti</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>gizli</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>yüklendi</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Elle</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>etkin</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>devre dışı</translation>
    </message>
    <message>
        <source>static</source>
        <translation>sabit</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>geçici</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>dolaylı</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>etkin çalışma zamanı</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>gizli</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>oluşturulan</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>öldür</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>ön başlat</translation>
    </message>
    <message>
        <source>start</source>
        <translation>başlat</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>direk başlat</translation>
    </message>
    <message>
        <source>running</source>
        <translation>çalışıyor</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>çıkıldı</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>yeniden yükle</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>durdur</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>watchdog&apos;u durdur</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>sigterm&apos;i durdur</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>sigkill&apos;i durdur</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>post&apos;u durdur</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>son sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>son sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>başarısız</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>otomatik yeniden başlat</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Kullanıldı</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Mevcut</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Paylaşıldı</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Önbelleklendi</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Arabellekler</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Önbelleklenen takas</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Pasif</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Kirli</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Haritalandı</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Toplam takas </translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Boş takas</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Levha</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Okuma hızı</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Yazma hızı</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapasite</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Bölgeler okundu</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Okur/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Bölgeler okundu/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Okumalar birleştirildi/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Bölgeler yazıldı</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Yazılar tamamlandı</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Yazılar birleştirildi</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Yazar/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Bölgeler yazıldı/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Yazılar birleştirildi/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Bu işlemi sonlandırmak veri kaybına neden olabilir.
Devam etmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>İşlemi sonlandır</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Bu işlemi zorla sonlandırmak veri kaybına neden olabilir.
Devam etmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Bu uygulamayı sonlandırmaya zorlamak veri kaybına neden olabilir.
Devam etmek istediğine emin misin?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Zorla Sonlandır</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Sonlandır</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP adresi:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Ağ maskesi:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Kapsam:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Bağlantı türü</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Bağlantı kalitesi</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Sinyal gücü</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Bozukluk seviyesi</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Bant genişliği</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX paketler</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX bayt</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX hataları</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX düştü</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX aşımı</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX çerçevesi</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX paketler</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX bayt</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX hataları</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX aşımı</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX taşıyıcısı</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX düştü</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Komut satırı</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Başlama zamanı</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Sonlandırmak istediğiniz uygulamayı tıklayın</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Alınan</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disk okuma</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk yazma</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Takas</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Etkin değil</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndirme</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükleme</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Toplam Alınan</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Toplam Gönderilen</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gönderilen</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diskler</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Çok yüksek</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Yüksek</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Düşük</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Çok düşük</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Özel</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Geçersiz</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Hata: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>İşlem önceliği değiştirilemedi</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>İşlemlerim</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tüm işlemler</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Yükleniyor</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>İşlem duraklatılamadı</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>İşlem sürdürülemedi</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>İşlem öldürülemedi</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>İşleme alınacak sinyal gönderilemedi</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>İşlem sona erdirilemedi</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 uygulama ve %2 işlem çalışıyor)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Yanıt yok</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Tepsi</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Komut konumunu görüntüle</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Özellikler</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>İşlemi sonlandır</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>İşlemi sürdür</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Süreçleri öldür</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Önceliği değiştir</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>İşlemi askıya al</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Özel Öncelik</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Değiştir</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Bellek</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Disk yazma</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disk okuma</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndirme</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükleme</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Güzel</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Öncelik</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Paylaşılan bellek</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Sanal bellek</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Desteklenmiyor</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Sistem Koruması</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Kullanım eşikleri aşıldığında uyarı göster</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Bildirimler</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>CPU uyarı eşiği (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Bellek uyarı eşiği (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Uyarı aralığı (dk)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Hizmet başlangıç türü ayarlanamadı</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Hata: Alt işlem çöktüğü için hizmet başlatma türü ayarlanamadı.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Hizmet örneği adı</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Yenile</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Elle</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Başlangıç türü</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Yükle</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Başlangıç Türü</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Değiştirilebilir)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Aralık: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Uygulamayı zorla sonlandır</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Genişlet</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Sade</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>İşlemler</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Hizmetler</translation>
    </message>
</context>
</TS>
